@@ -20,9 +20,9 @@ class LoanQueryInput(BaseModel):
 class LoanQueryRun(BaseTool):
     """Tool for the Loan API (get user's loan profiles)."""
 
-    name: str = "personal_loan"
+    name: str = "loan"
     description: str = (
-        "A wrapper for personal loan. "
+        "A wrapper for loan. "
         "Useful for when you need to answer questions about current user's loans. "
         "Get user's loan profiles."
     )
